Plugin: JS9PanZoom

### JS9 Pan/Zoom Controls

The Pan/Zoom Controls plugin allows you to pan to an image location that can be specified using image, physical, or WCS coordinates.

The plugin initially displays the current pan location using the current globally configured WCS system and units. Choose a different system and/or units via the WCS system and WCS units menus and the current pan position will be updated appropriately. Then enter a new position in the position text boxes and click the Pan to → button to pan the image.

The plugin also offers menus to pan, zoom, flip, and rotate the image by 90 degree increments, along with a text box to rotate by an arbitrary angle in degrees. Note that arbitrary rotation is performed in terms of an absolute angle: if you rotate by 20 degrees and then do it again, there is no change. Also, setting the rotation to 0 sets the angle to 0. Flipping and rot90, however, are relative to the current state of the display.

The Flip menu's reset option unsets x and/or y flips. The Rotate menu's reset option resets both the rot90 and rotation angle, as does specifying reset in the rotation text box. The Rotate menu's reset flip/rot90/rotate option resets flip, rot90, and rotate.